========
ds_store
========

.. image:: https://img.shields.io/pypi/pyversions/ds_store.svg
   :target: https://pypi.python.org/pypi/ds_store
   :alt: Python Versions

.. image:: https://img.shields.io/pypi/v/ds_store.svg
   :target: https://pypi.python.org/pypi/ds_store
   :alt: PyPI Version

.. image:: https://img.shields.io/pypi/status/ds_store.svg
   :target: https://pypi.python.org/pypi/ds_store
   :alt: Maturity

.. image:: https://img.shields.io/pypi/l/ds_store.svg
   :target: https://github.com/dmgbuild/ds_store/blob/main/LICENSE
   :alt: MIT License

.. image:: https://github.com/dmgbuild/ds_store/workflows/CI/badge.svg?branch=main
   :target: https://github.com/dmgbuild/ds_store/actions
   :alt: Build Status

.. image:: https://readthedocs.org/projects/ds_store/badge/?version=latest
   :target: http://ds_store.readthedocs.io/en/latest/?badge=latest
   :alt: Docs Build Status

What is this?
-------------

``ds_store`` lets you examine and modify ``.DS_Store`` files from Python
code; since it is written in pure Python, it is portable and will run on any
platform, not just Mac OS X.

Credit is due to Wim Lewis, Mark Mentovai and Yvan Barthélemy for
reverse-engineering the .DS_Store file format. See
`Wim Lewis’ excellent documentation on CPAN`__ for more information.

__ http://search.cpan.org/~wiml/Mac-Finder-DSStore/DSStoreFormat.pod
